@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-from testcli.global_var import globalEmbeddScriptScope
-from testcli.global_var import localEmbeddScriptScope
-from testcli.global_var import lastCommandResult
+from testcli.globalvar import globalEmbeddScriptScope
+from testcli.globalvar import localEmbeddScriptScope
+from testcli.globalvar import lastCommandResult
 
 
 # 执行Python脚本
